@@ -1,8 +1,7 @@
 #[cfg(feature = "js-esbuild")]
 use {
     crate::minify::esbuild::minify_using_esbuild,
-    aho_corasick::{AhoCorasick, AhoCorasickBuilder},
-    esbuild_rs::{TransformOptions, TransformOptionsBuilder},
+    esbuild_rs::{Charset, LegalComments, SourceMap, TransformOptions, TransformOptionsBuilder},
     lazy_static::lazy_static,
     std::sync::Arc,
 };
@@ -11,14 +10,14 @@ use crate::Cfg;
 
 #[cfg(feature = "js-esbuild")]
 lazy_static! {
-    static ref SCRIPT_END: AhoCorasick = AhoCorasickBuilder::new()
-        .ascii_case_insensitive(true)
-        .build(&["</script"]);
     static ref TRANSFORM_OPTIONS: Arc<TransformOptions> = {
         let mut builder = TransformOptionsBuilder::new();
+        builder.charset = Charset::UTF8;
+        builder.legal_comments = LegalComments::None;
         builder.minify_identifiers = true;
         builder.minify_syntax = true;
         builder.minify_whitespace = true;
+        builder.source_map = SourceMap::None;
         builder.build()
     };
 }
@@ -33,6 +32,6 @@ pub fn minify_js(cfg: &Cfg, out: &mut Vec<u8>, code: &[u8]) {
     if !cfg.minify_js {
         out.extend_from_slice(&code);
     } else {
-        minify_using_esbuild(out, code, &TRANSFORM_OPTIONS.clone(), Some(&SCRIPT_END));
+        minify_using_esbuild(out, code, &TRANSFORM_OPTIONS.clone());
     }
 }
